atomate.feff.workflows package — atomate 0.9.2 documentation

# atomate.feff.workflows package

## Subpackages

- atomate.feff.workflows.tests package
  - Submodules
  - atomate.feff.workflows.tests.test_eels_workflows module
  - atomate.feff.workflows.tests.test_exafs_scattering_paths module
  - atomate.feff.workflows.tests.test_xas_workflows module
  - Module contents

## Submodules

## atomate.feff.workflows.core module

`atomate.feff.workflows.core.` `get_absorbing_atom_indices`(structure, absorbing_atom)
  Args:

    structure (Structure): absorbing_atom (int/str):

  Returns:

    list of site ids

`atomate.feff.workflows.core.` `get_unique_site_indices`(structure)

`atomate.feff.workflows.core.` `get_wf_eels`(absorbing_atom, structure=None, feff_input_set='pymatgen.io.feff.sets.MPELNESSet', edge='K', radius=10.0, beam_energy=100, beam_direction=None, collection_angle=1, convergence_angle=1, user_eels_settings=None, user_tag_settings=None, feff_cmd='feff', db_file=None, metadata=None, use_primitive=False)

  Returns FEFF ELNES/EXELFS spectroscopy workflow.

  Args:

    absorbing_atom (str): absorbing atom symbol structure (Structure): input structure. If None and mp_id is provided, the corresponding

    > structure will be fetched from the Materials Project db.

    feff_input_set (str or FeffDictSet subclass): The inputset for setting params. If string

      then either the entire path to the class or spectrum type must be provided e.g. “pymatgen.io.feff.sets.MPELNESSet” or “ELNES”

    edge (str): absorption edge. K, L1, L2, L3 radius (float): cluster radius in angstroms. Ignored for reciprocal space calculations beam_energy (float): the incident beam energy in keV beam_direction (list): incident beam direction. Default is none ==> the spectrum will be

    > averaged over all directions.

    collection_angle (float): collection angle in mrad convergence_angle (float): convergence angle in mrad user_eels_settings (dict): override default eels settings. user_tag_settings (dict): override other general feff default tag settings. feff_cmd (str): path to the feff binary db_file (str): path to the db file. metadata (dict): meta data use_primitive (bool): convert the structure to primitive form. This helps to

    > reduce the number of fireworks in the workflow if the absorbing atoms is specified by its atomic symbol.

  Returns:

    Workflow

`atomate.feff.workflows.core.` `get_wf_exafs_paths`(absorbing_atom, structure, paths, degeneracies=None, edge='K', radius=10.0, feff_input_set='pymatgen.io.feff.sets.MPEXAFSSet', feff_cmd='feff', db_file=None, metadata=None, user_tag_settings=None, use_primitive=False, labels=None, filepad_file=None)

  Returns FEFF EXAFS spectroscopy workflow that generates the scattering amplitudes for the given list of scattering paths. The scattering amplitude output files(feffNNNN.dat files) are inserted to filepad(see fireworks.utilities.filepad.py) on completion.

  Args:
    absorbing_atom (str/int): absorbing atom symbol or site index. If the symbol is given,

      then the returned workflow will have fireworks for each absorbing site with the same symbol.

    structure (Structure): input structure paths (list): list of paths. path = list of site indices. degeneracies (list): list of path degeneracies. edge (str): absorption edge. Example: K, L1, L2, L3 radius (float): cluster radius in angstroms. Ignored for K space calculations feff_input_set (str or FeffDictSet subclass): The inputset for setting params. If string

    > then the entire path to the class must be provided e.g. “pymatgen.io.feff.sets.MPEXAFSSet”

    feff_cmd (str): path to the feff binary db_file (str): path to the db file. metadata (dict): meta data user_tag_settings (dict): override feff default tag settings use_primitive (bool): convert the structure to primitive form. This helps to

    > reduce the number of fireworks in the workflow if the absorbing atom is specified by its atomic symbol.

    labels ([str]): list of labels for the scattering amplitudes file contents inserted into

      filepad. Useful for fetching the data from filepad later.

    filepad_file (str): path to filepad connection settings file.

  Returns:

    Workflow

`atomate.feff.workflows.core.` `get_wf_xas`(absorbing_atom, structure, feff_input_set='pymatgen.io.feff.sets.MPXANESSet', edge='K', radius=10.0, feff_cmd='feff', db_file=None, metadata=None, user_tag_settings=None, use_primitive=False)

  Returns FEFF XANES/EXAFS spectroscopy workflow.

  Args:
    absorbing_atom (str/int): absorbing atom symbol or site index. If the symbol is given,

      then the returned workflow will have fireworks for each absorbing site with the same symbol.

    structure (Structure): input structure feff_input_set (str or FeffDictSet subclass): The inputset for setting params. If string

    > then either the entire path to the class or spectrum type must be provided e.g. “pymatgen.io.feff.sets.MPXANESSet” or “XANES”

    edge (str): absorption edge. Example: K, L1, L2, L3 radius (float): cluster radius in angstroms. Ignored for K space calculations feff_cmd (str): path to the feff binary db_file (str): path to the db file. metadata (dict): meta data user_tag_settings (dict): override feff default tag settings use_primitive (bool): convert the structure to primitive form. This helps to

    > reduce the number of fireworks in the workflow if the absorbing atom is specified by its atomic symbol.

  Returns:

    Workflow

## atomate.feff.workflows.presets module

`atomate.feff.workflows.presets.` `wf_Xanes_K_edge`(structure, c=None)

## Module contents